Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/msa301_simpletest.py
    :caption: examples/msa301_simpletest.py
    :linenos:

Tap test
--------

Check out the tap capability with this example.

.. literalinclude:: ../examples/msa301_tap_example.py
    :caption: examples/msa301_tap_example.py
    :linenos:
